from django.db import models
from django.utils.translation import ugettext_lazy as _


class ProductTypes(models.TextChoices):
    SUBS = "subscription"
    IN_APP_CURR = "in-app-currency"


class Product(models.Model):
    product_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=50)
    description = models.TextField(max_length=1000, blank=True, null=True)
    type = models.CharField(max_length=15, choices=ProductTypes.choices, default=ProductTypes.SUBS)
    valid_from = models.DateField(blank=True, null=True)
    valid_to = models.DateField(blank=True, null=True)
    product_id_ios = models.CharField(max_length=50, blank=True, null=True)
    product_id_android = models.CharField(max_length=50, blank=True, null=True)
    price_ios = models.DecimalField(max_length=12, decimal_places=2, max_digits=12, blank=True)
    price_android = models.DecimalField(max_length=12, decimal_places=2, max_digits=12, blank=True)

    class Meta:
        db_table = 'product'
        verbose_name = _("Product")
        verbose_name_plural = _("Products")

    def __str__(self):
        return self.name


class Purchase(models.Model):
    purchase_id = models.AutoField(primary_key=True)
    product = models.ForeignKey(Product, on_delete=models.CASCADE)
    customer_id = models.IntegerField()
    date_add = models.DateField(blank=True, null=True)
    purchase_sum = models.DecimalField(decimal_places=2, max_digits=7)
    currency = models.CharField(max_length=3)

    class Meta:
        db_table = 'purchase'
        verbose_name = _("Purchase")
        verbose_name_plural = _("Purchases")