from django.db import models
from django.utils.translation import ugettext_lazy as _
from ckeditor.fields import RichTextField

from .enums import LanguageTypes


class TrainingPlanDay(models.Model):
    day_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=200, help_text='Unique description name',
                            verbose_name=_("name"))

    class Meta:
        db_table = 'training_plan_day'
        verbose_name = _("Training Day")
        verbose_name_plural = _("Training Days")

    def __str__(self):
        return self.name


class TrainingPlanDayTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    day = models.ForeignKey(TrainingPlanDay, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    name_translation = models.CharField(max_length=200, help_text='Unique description name',
                            verbose_name=_("name"))

    class Meta:
        db_table = 'training_plan_day_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")
